You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@maven.apache.org by hb...@apache.org on 2015/12/28 16:31:23 UTC

svn commit: r1721939 - in /maven/doxia/doxia-sitetools/trunk/doxia-site-renderer/src/main/java/org/apache/maven/doxia/siterenderer: DefaultSiteRenderer.java SiteRenderingContext.java

Author: hboutemy
Date: Mon Dec 28 15:31:22 2015
New Revision: 1721939

URL: http://svn.apache.org/viewvc?rev=1721939&view=rev
Log:
[DOXIASITETOOLS-133] renamed velocityDocumentOutput to more generic processedContentOutput

Modified:
    maven/doxia/doxia-sitetools/trunk/doxia-site-renderer/src/main/java/org/apache/maven/doxia/siterenderer/DefaultSiteRenderer.java
    maven/doxia/doxia-sitetools/trunk/doxia-site-renderer/src/main/java/org/apache/maven/doxia/siterenderer/SiteRenderingContext.java

Modified: maven/doxia/doxia-sitetools/trunk/doxia-site-renderer/src/main/java/org/apache/maven/doxia/siterenderer/DefaultSiteRenderer.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia-sitetools/trunk/doxia-site-renderer/src/main/java/org/apache/maven/doxia/siterenderer/DefaultSiteRenderer.java?rev=1721939&r1=1721938&r2=1721939&view=diff
==============================================================================
--- maven/doxia/doxia-sitetools/trunk/doxia-site-renderer/src/main/java/org/apache/maven/doxia/siterenderer/DefaultSiteRenderer.java (original)
+++ maven/doxia/doxia-sitetools/trunk/doxia-site-renderer/src/main/java/org/apache/maven/doxia/siterenderer/DefaultSiteRenderer.java Mon Dec 28 15:31:22 2015
@@ -346,16 +346,16 @@ public class DefaultSiteRenderer
 
                     String doxiaContent = sw.toString();
 
-                    if ( siteContext.getVelocityDocumentOutput() != null )
+                    if ( siteContext.getProcessedContentOutput() != null )
                     {
                         // save Velocity processing result, ie the Doxia content that will be parsed after
-                        if ( !siteContext.getVelocityDocumentOutput().exists() )
+                        if ( !siteContext.getProcessedContentOutput().exists() )
                         {
-                            siteContext.getVelocityDocumentOutput().mkdirs();
+                            siteContext.getProcessedContentOutput().mkdirs();
                         }
 
                         String input = renderingContext.getInputName();
-                        File outputFile = new File( siteContext.getVelocityDocumentOutput(),
+                        File outputFile = new File( siteContext.getProcessedContentOutput(),
                                                     input.substring( 0, input.length() - 3 ) );
 
                         File outputParent = outputFile.getParentFile();

Modified: maven/doxia/doxia-sitetools/trunk/doxia-site-renderer/src/main/java/org/apache/maven/doxia/siterenderer/SiteRenderingContext.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia-sitetools/trunk/doxia-site-renderer/src/main/java/org/apache/maven/doxia/siterenderer/SiteRenderingContext.java?rev=1721939&r1=1721938&r2=1721939&view=diff
==============================================================================
--- maven/doxia/doxia-sitetools/trunk/doxia-site-renderer/src/main/java/org/apache/maven/doxia/siterenderer/SiteRenderingContext.java (original)
+++ maven/doxia/doxia-sitetools/trunk/doxia-site-renderer/src/main/java/org/apache/maven/doxia/siterenderer/SiteRenderingContext.java Mon Dec 28 15:31:22 2015
@@ -71,7 +71,7 @@ public class SiteRenderingContext
 
     private Date publishDate;
 
-    private File velocityDocumentOutput;
+    private File processedContentOutput;
 
     /**
      * If input documents should be validated before parsing.
@@ -401,20 +401,23 @@ public class SiteRenderingContext
     }
 
     /**
      * Directory where to save documents after Velocity processing (*.vm), but before parsing them with Doxia.
      * @return not null if the documents are to be saved
      */
-    public File getVelocityDocumentOutput()
+    public File getProcessedContentOutput()
     {
-        return velocityDocumentOutput;
+        return processedContentOutput;
     }
 
     /**
      * Where to (eventually) save documents after Velocity processing (*.vm), but before parsing them with Doxia?
      * @param velocityDocumentOutput not null if the documents are to be saved
      */
-    public void setVelocityDocumentOutput( File velocityDocumentOutput )
+    public void setProcessedContentOutput( File processedContentOutput )
     {
-        this.velocityDocumentOutput = velocityDocumentOutput;
+        this.processedContentOutput = processedContentOutput;
     }
 }
@@ -401,20 +401,23 @@ public class SiteRenderingContext
 
     /**
-     * Directory where to save documents after Velocity processing (*.vm), but before parsing them with Doxia.
+     * Directory where to save content after Velocity processing (<code>*.vm</code>), but before parsing it with Doxia.
+     * 
      * @return not null if the documents are to be saved
      */
@@ -401,20 +401,23 @@ public class SiteRenderingContext
 
     /**
-     * Where to (eventually) save documents after Velocity processing (*.vm), but before parsing them with Doxia?
-     * @param velocityDocumentOutput not null if the documents are to be saved
+     * Where to (eventually) save content after Velocity processing (<code>*.vm</code>), but before parsing it with
+     * Doxia?
+     * 
+     * @param processedContentOutput not null if the documents are to be saved
      */